#[repr(u8)]pub enum Msbf {
LSB_FIRST = 0,
MSB_FIRST = 1,
}Variants
LSB_FIRST = 0
LSB (bit0) is the first bit that is transmitted following the start bit. Further, the first bit received after the start bit is identified as bit0.
MSB_FIRST = 1
MSB (identified as bit9, bit8, bit7 or bit6) is the first bit that is transmitted following the start bit depending on the setting of CTRL[M], CTRL[PE] and BAUD[M10]. .
Implementations